@@ -95,6 +95,78 @@ def report(input, output):
     output.write(template.render(**_report.from_input(input)))
 
 
+@main.command()
+@click.option(
+    "--format",
+    "-f",
+    help="What format to use for the output",
+    default=None,
+    type=click.Choice(["json", "pretty"]),
+)
+@click.argument(
+    "input",
+    default="-",
+    type=click.File(mode="r"),
+)
+def summary(input, format):
+    """
+    Generate an (in-terminal) summary of a Bowtie run.
+    """
+    if format is None:
+        format = "pretty" if sys.stdout.isatty() else "json"
+
+    summary = _report.from_input(input)["summary"]
+    counts = (
+        (
+            (implementation["name"], implementation["language"]),
+            summary.counts[implementation["image"]],
+        )
+        for implementation in summary.implementations
+    )
+
+    combined = [
+        (
+            metadata,
+            {
+                "errored": each.errored_tests,
+                "failed": each.failed_tests,
+                "skipped": each.skipped_tests,
+            },
+        )
+        for metadata, each in counts
+    ]
+    ordered = sorted(
+        combined,
+        key=lambda each: (sum(each[1].values()), each[0][0]),
+        reverse=True,
+    )
+
+    if format == "json":
+        click.echo(json.dumps(ordered, indent=2))
+    else:
+        from rich.table import Table
+        from rich.text import Text
+
+        test = "tests" if summary.total_tests != 1 else "test"
+        table = Table(
+            "Implementation",
+            "Skips",
+            "Errors",
+            "Failures",
+            title="Bowtie",
+            caption=f"{summary.total_tests} {test} ran",
+        )
+        for (implementation, language), counts in ordered:
+            table.add_row(
+                Text.assemble(implementation, (f" ({language})", "dim")),
+                str(counts["skipped"]),
+                str(counts["errored"]),
+                str(counts["failed"]),
+            )
+
+        console.Console().print(table)
+
+
 def validator_for_dialect(dialect: str | None = None):
     from jsonschema.validators import RefResolver, validator_for
 
@@ -237,6 +309,57 @@ def validate(context, schema, instances, **kwargs):
     context.exit(exit_code)
 
 
+@main.command()
+@click.pass_context
+@IMPLEMENTATION
+def info(context, **kwargs):
+    """
+    Retrieve a particular implementation (harness)'s metadata.
+    """
+    exit_code = asyncio.run(_info(**kwargs))
+    context.exit(exit_code)
+
+
+async def _info(image_names: list[str]):
+    exit_code = 0
+    async with _start(
+        image_names=image_names,
+        make_validator=validator_for_dialect,
+        reporter=_report.Reporter(),
+    ) as starting:
+        for each in asyncio.as_completed(starting):
+            try:
+                implementation = await each
+            except NoSuchImage as error:
+                exit_code |= os.EX_CONFIG
+                click.echo(
+                    f"❗ (error): {error.name!r} is not a known Bowtie implementation.",  # noqa: E501
+                )
+                continue
+
+            if implementation.metadata is None:
+                exit_code |= os.EX_CONFIG
+                click.echo("  ❗ (error): startup failed")
+                continue
+
+            click.echo(
+                "\n".join(
+                    f"{k}: {json.dumps(v, indent=2)}"
+                    for k, v in sorted(
+                        implementation.metadata.items(),
+                        key=lambda kv: (
+                            kv[0] != "name",
+                            kv[0] != "language",
+                            kv[0] != "version",
+                            kv[0] == "dialects",
+                            kv[0],
+                        ),
+                    )
+                ),
+            )
+    return exit_code
+
+
 @main.command()
 @click.pass_context
 @IMPLEMENTATION
@@ -253,7 +376,7 @@ async def _smoke(image_names: list[str]):
     async with _start(
         image_names=image_names,
         make_validator=validator_for_dialect,
-        reporter=None,  # FIXME: we don't want to print anything here
+        reporter=_report.Reporter(),
     ) as starting:
         for each in asyncio.as_completed(starting):
             try:
@@ -294,10 +417,10 @@ async def _smoke(image_names: list[str]):
             ]
             for seq, case in enumerate(cases):
                 response = await runner.run_case(seq=seq, case=case)
-                if response.errored:
+                if response.errored:  # type: ignore[reportGeneralTypeIssues]  # noqa: E501
                     exit_code |= os.EX_DATAERR
                     message = "❗ (error)"
-                elif response.failed:
+                elif response.failed:  # type: ignore[reportGeneralTypeIssues]  # noqa: E501
                     exit_code |= os.EX_DATAERR
                     message = "✗ (failed)"
                 else:
@@ -317,7 +440,7 @@ class _TestSuiteCases(click.ParamType):
     name = "json-schema-org/JSON-Schema-Test-Suite test cases"
 
     def convert(self, value, param, ctx):
-        if not isinstance(value, (Path, str)):
+        if not isinstance(value, str):
             return value
 
         is_local_path = not value.casefold().startswith(TEST_SUITE_URL)
