@@ -3,14 +3,21 @@ from __future__ import annotations
 from collections import deque
 from collections.abc import Callable
 from contextlib import asynccontextmanager
+from typing import TYPE_CHECKING
 import asyncio
 import json
 
 from attrs import field, frozen, mutable
-import aiodocker
+import aiodocker.containers
+import aiodocker.docker
+import aiodocker.exceptions
+import aiodocker.stream
 
 from bowtie import _commands, exceptions
 
+if TYPE_CHECKING:
+    from bowtie._report import Reporter
+
 
 @frozen
 class GotStderr(Exception):
@@ -24,6 +31,11 @@ class StartupFailed(Exception):
     name: str
     stderr: str = ""
 
+    def __str__(self):
+        if self.stderr:
+            return f"{self.name}'s stderr contained: {self.stderr}"
+        return self.name
+
 
 @frozen
 class NoSuchImage(Exception):
@@ -41,9 +53,9 @@ class Stream:
     Wrapper to make aiodocker's Stream more pleasant to use.
     """
 
-    _stream: aiodocker.stream.Stream
-    _container: aiodocker.containers.DockerContainer
-    _buffer: deque[bytes] = field(factory=deque)
+    _stream: aiodocker.stream.Stream = field(alias="stream")
+    _container: aiodocker.containers.DockerContainer = field(alias="container")
+    _buffer: deque[bytes] = field(factory=deque, alias="buffer")
     _last: bytes = b""
 
     @classmethod
@@ -60,7 +72,7 @@ class Stream:
 
     async def receive(self):
         if self._buffer:
-            return json.loads(self._buffer.popleft())
+            return self._buffer.popleft()
 
         while True:
             message = await self._read_with_timeout()
@@ -84,7 +96,7 @@ class Stream:
             if rest:
                 line, self._last = self._last + line, rest.pop()
                 self._buffer.extend(rest)
-                return json.loads(line)
+                return line
 
             message = None
             while message is None:
@@ -95,10 +107,10 @@ class Stream:
 @frozen
 class DialectRunner:
 
-    _name: str
-    _dialect: str
-    _send: Callable
-    _start_response: _commands.StartedDialect
+    _name: str = field(alias="name")
+    _dialect: str = field(alias="dialect")
+    _send: Callable = field(alias="send")
+    _start_response: _commands.StartedDialect = field(alias="start_response")
 
     @classmethod
     async def start(cls, send, dialect, name):
@@ -142,17 +154,18 @@ class Implementation:
 
     name: str
 
-    _make_validator: Callable
-    _maybe_validate: Callable
-    _reporter: object
+    _make_validator: Callable = field(alias="make_validator")
+    _maybe_validate: Callable = field(alias="maybe_validate")
+    _reporter: Reporter = field(alias="reporter")
 
-    _docker: aiodocker.Docker = field(repr=False)
-    _restarts: int = field(default=20, repr=False)
+    _docker: aiodocker.docker.Docker = field(repr=False, alias="docker")
+    _restarts: int = field(default=20, repr=False, alias="restarts")
     _container: aiodocker.containers.DockerContainer = field(
         default=None,
         repr=False,
+        alias="container",
     )
-    _stream: Stream = field(default=None, repr=False)
+    _stream: Stream = field(default=None, repr=False, alias="stream")
 
     metadata: dict | None = None
 
