@@ -1,3 +1,8 @@
+"""
+Errors. Oh no!
+"""
+from __future__ import annotations
+
 from typing import TYPE_CHECKING
 
 from attrs import frozen
@@ -12,7 +17,7 @@ class StartupFailure(Exception):
     An implementation failed to start properly.
     """
 
-    implementation: "Implementation"
+    implementation: Implementation
     stderr: bytes
 
 
@@ -22,8 +27,6 @@ class ImplementationNotReady(Exception):
     An implementation said it was not ready.
     """
 
-    implementation: "Implementation"
-
 
 @frozen
 class VersionMismatch(Exception):
@@ -31,7 +34,6 @@ class VersionMismatch(Exception):
     The wrong protocol version was returned from an implementation.
     """
 
-    implementation: "Implementation"
     expected: int
     got: int
 
