@@ -73,6 +73,13 @@ fail_on_run = strimplementation(
     CMD read && printf '{"implementation": {"dialects": ["urn:foo"]}, "ready": true, "version": 1}\n' && read && printf 'BOOM!\n' >&2
     """,  # noqa: E501
 )
+wrong_version = strimplementation(
+    name="wrong_version",
+    contents=r"""
+    FROM alpine:3.16
+    CMD read && printf '{"implementation": {"dialects": ["urn:foo"]}, "ready": true, "version": 0}\n' && read >&2
+    """,  # noqa: E501
+)
 hit_the_network = strimplementation(
     name="hit_the_network",
     contents=r"""
@@ -315,7 +322,7 @@ async def test_it_prevents_network_access(hit_the_network):
     Don't uselessly "run" tests on no implementations.
     """
     async with bowtie("-i", hit_the_network, "--dialect", "urn:foo") as send:
-        returncode, results, errors, cases, stderr = await send(
+        returncode, results, _, _, stderr = await send(
             """
             {"description": "1", "schema": {}, "tests": [{"description": "foo", "instance": {}}] }
             """,  # noqa: E501
@@ -325,6 +332,29 @@ async def test_it_prevents_network_access(hit_the_network):
     assert b"bad address" in stderr.lower(), stderr
 
 
+@pytest.mark.asyncio
+async def test_wrong_version(wrong_version):
+    """
+    An implementation speaking the wrong version of the protocol is skipped.
+    """
+    async with bowtie(
+        "-i",
+        wrong_version,
+        "--dialect",
+        "urn:foo",
+        succeed=False,
+    ) as send:
+        returncode, results, _, _, stderr = await send(
+            """
+            {"description": "1", "schema": {}, "tests": [{"description": "valid:1", "instance": {}, "valid": true}] }
+            """,  # noqa: E501
+        )
+
+    assert results == [], stderr
+    assert b"VersionMismatch: (1, 0)" in stderr, stderr
+    assert returncode != 0, stderr
+
+
 @pytest.mark.asyncio
 async def test_fail_fast(envsonschema):
     async with bowtie("-i", envsonschema, "-x") as send:
@@ -375,6 +405,38 @@ async def test_smoke(envsonschema):
     assert proc.returncode != 0
 
 
+@pytest.mark.asyncio
+async def test_info(envsonschema):
+    proc = await asyncio.create_subprocess_exec(
+        sys.executable,
+        "-m",
+        "bowtie",
+        "info",
+        "-i",
+        envsonschema,
+        stdout=asyncio.subprocess.PIPE,
+        stderr=asyncio.subprocess.PIPE,
+    )
+    stdout, stderr = await proc.communicate()
+    assert proc.returncode == 0, (stdout, stderr)
+    assert stdout.decode() == dedent(
+        """\
+        name: "envsonschema"
+        language: "python"
+        issues: "https://github.com/bowtie-json-schema/bowtie/issues"
+        dialects: [
+          "https://json-schema.org/draft/2020-12/schema",
+          "https://json-schema.org/draft/2019-09/schema",
+          "http://json-schema.org/draft-07/schema#",
+          "http://json-schema.org/draft-06/schema#",
+          "http://json-schema.org/draft-04/schema#",
+          "http://json-schema.org/draft-03/schema#"
+        ]
+        """,
+    )
+    assert stderr == b""
+
+
 @pytest.mark.asyncio
 async def test_validate(envsonschema, tmp_path):
     tmp_path.joinpath("schema.json").write_text("{}")
@@ -398,6 +460,43 @@ async def test_validate(envsonschema, tmp_path):
     assert proc.returncode == 0
 
 
+@pytest.mark.asyncio
+async def test_summary(envsonschema, tmp_path):
+    tmp_path.joinpath("schema.json").write_text("{}")
+    tmp_path.joinpath("instance.json").write_text("12")
+
+    validate = await asyncio.create_subprocess_exec(
+        sys.executable,
+        "-m",
+        "bowtie",
+        "validate",
+        "-i",
+        envsonschema,
+        tmp_path / "schema.json",
+        tmp_path / "instance.json",
+        stdout=asyncio.subprocess.PIPE,
+        stderr=asyncio.subprocess.PIPE,
+    )
+    validate_stdout, _ = await validate.communicate()
+
+    summary = await asyncio.create_subprocess_exec(
+        sys.executable,
+        "-m",
+        "bowtie",
+        "summary",
+        "--format",
+        "json",
+        stdin=asyncio.subprocess.PIPE,
+        stdout=asyncio.subprocess.PIPE,
+        stderr=asyncio.subprocess.PIPE,
+    )
+    stdout, stderr = await summary.communicate(validate_stdout)
+    assert stderr == b""
+    assert json.loads(stdout) == [
+        [["envsonschema", "python"], dict(errored=0, failed=0, skipped=0)],
+    ]
+
+
 @pytest.mark.asyncio
 async def test_no_such_image():
     proc = await asyncio.create_subprocess_exec(
